summaryrefslogtreecommitdiffstats
path: root/test/cache_common.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2010-05-06 15:39:23 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2010-05-06 15:39:23 (GMT)
commitabd749619d15cf7a3e927232ac2ad7ed1c726dd2 (patch)
treec722e8827c02f11e97b1106e2cb016c65b1b6eb5 /test/cache_common.c
parentb95c7d1879120c542490c031c70b88f6e5fa7eaa (diff)
downloadhdf5-abd749619d15cf7a3e927232ac2ad7ed1c726dd2.zip
hdf5-abd749619d15cf7a3e927232ac2ad7ed1c726dd2.tar.gz
hdf5-abd749619d15cf7a3e927232ac2ad7ed1c726dd2.tar.bz2
[svn-r18726] Description:
Bring r18725 from trunk to 1.8 branch: Bring r18724 from metadata journaling 'merging' branch to trunk: Rename H5[A]C_rename to H5[A]C_move_entry. Tested on: FreeBSD/32 6.3 (duty) w/debug (h5committested on trunk)
Diffstat (limited to 'test/cache_common.c')
-rw-r--r--test/cache_common.c44
1 files changed, 22 insertions, 22 deletions
diff --git a/test/cache_common.c b/test/cache_common.c
index 090e102..145e9b5 100644
--- a/test/cache_common.c
+++ b/test/cache_common.c
@@ -1475,8 +1475,8 @@ execute_flush_op(H5F_t * file_ptr,
}
break;
- case FLUSH_OP__RENAME:
- rename_entry(cache_ptr, op_ptr->type, op_ptr->idx,
+ case FLUSH_OP__MOVE:
+ move_entry(cache_ptr, op_ptr->type, op_ptr->idx,
op_ptr->flag);
break;
@@ -2873,9 +2873,9 @@ mark_entry_dirty(int32_t type,
/*-------------------------------------------------------------------------
- * Function: rename_entry()
+ * Function: move_entry()
*
* Purpose: Rename the entry indicated by the type and index to its
* main or alternate address as indicated. If the entry is
* already at the desired entry, do nothing.
*
@@ -2888,7 +2888,7 @@ mark_entry_dirty(int32_t type,
*/
void
-rename_entry(H5C_t * cache_ptr,
+move_entry(H5C_t * cache_ptr,
int32_t type,
int32_t idx,
hbool_t main_addr)
@@ -2917,7 +2917,7 @@ rename_entry(H5C_t * cache_ptr,
if ( entry_ptr->at_main_addr && !main_addr ) {
/* rename to alt addr */
HDassert( entry_ptr->addr == entry_ptr->main_addr );
@@ -2927,7 +2927,7 @@ rename_entry(H5C_t * cache_ptr,
} else if ( !(entry_ptr->at_main_addr) && main_addr ) {
/* rename to main addr */
HDassert( entry_ptr->addr == entry_ptr->alt_addr );
@@ -2940,7 +2940,7 @@ rename_entry(H5C_t * cache_ptr,
entry_ptr->is_dirty = TRUE;
- result = H5C_rename_entry(cache_ptr, &(types[type]),
+ result = H5C_move_entry(cache_ptr, &(types[type]),
old_addr, new_addr);
}
@@ -2951,7 +2951,7 @@ rename_entry(H5C_t * cache_ptr,
( entry_ptr->header.addr != new_addr ) ) ) {
pass = FALSE;
- failure_mssg = "error in H5C_rename_entry().";
+ failure_mssg = "error in H5C_move_entry().";
} else {
@@ -2967,7 +2967,7 @@ rename_entry(H5C_t * cache_ptr,
return;
-} /* rename_entry() */
+} /* move_entry() */
/*-------------------------------------------------------------------------
@@ -3499,7 +3499,7 @@ unprotect_entry_with_size_change(H5F_t * file_ptr,
/*-------------------------------------------------------------------------
* Function: row_major_scan_forward()
*
* Purpose: Do a sequence of inserts, protects, unprotects, renames,
* destroys while scanning through the set of entries. If
* pass is false on entry, do nothing.
*
@@ -3520,8 +3520,8 @@ row_major_scan_forward(H5F_t * file_ptr,
hbool_t display_detailed_stats,
hbool_t do_inserts,
hbool_t dirty_inserts,
- hbool_t do_renames,
- hbool_t rename_to_main_addr,
+ hbool_t do_moves,
+ hbool_t move_to_main_addr,
hbool_t do_destroys,
hbool_t do_mult_ro_protects,
int dirty_destroys,
@@ -3595,12 +3595,12 @@ row_major_scan_forward(H5F_t * file_ptr,
}
- if ( ( pass ) && ( do_renames ) && ( (idx + lag - 2) >= 0 ) &&
+ if ( ( pass ) && ( do_moves ) && ( (idx + lag - 2) >= 0 ) &&
( (idx + lag - 2) <= max_indices[type] ) &&
( ( (idx + lag - 2) % 3 ) == 0 ) ) {
- rename_entry(cache_ptr, type, (idx + lag - 2),
- rename_to_main_addr);
+ move_entry(cache_ptr, type, (idx + lag - 2),
+ move_to_main_addr);
}
@@ -3919,7 +3919,7 @@ hl_row_major_scan_forward(H5F_t * file_ptr,
/*-------------------------------------------------------------------------
* Function: row_major_scan_backward()
*
* Purpose: Do a sequence of inserts, protects, unprotects, renames,
* destroys while scanning backwards through the set of
* entries. If pass is false on entry, do nothing.
*
@@ -3940,8 +3940,8 @@ row_major_scan_backward(H5F_t * file_ptr,
hbool_t display_detailed_stats,
hbool_t do_inserts,
hbool_t dirty_inserts,
- hbool_t do_renames,
- hbool_t rename_to_main_addr,
+ hbool_t do_moves,
+ hbool_t move_to_main_addr,
hbool_t do_destroys,
hbool_t do_mult_ro_protects,
int dirty_destroys,
@@ -4009,12 +4009,12 @@ row_major_scan_backward(H5F_t * file_ptr,
}
- if ( ( pass ) && ( do_renames ) && ( (idx - lag + 2) >= 0 ) &&
+ if ( ( pass ) && ( do_moves ) && ( (idx - lag + 2) >= 0 ) &&
( (idx - lag + 2) <= max_indices[type] ) &&
( ( (idx - lag + 2) % 3 ) == 0 ) ) {
- rename_entry(cache_ptr, type, (idx - lag + 2),
- rename_to_main_addr);
+ move_entry(cache_ptr, type, (idx - lag + 2),
+ move_to_main_addr);
}
@@ -2873,9 +2873,9 @@ mark_entry_dirty(int32_t type,
*
- * Purpose: Rename the entry indicated by the type and index to its
+ * Purpose: move the entry indicated by the type and index to its
* main or alternate address as indicated. If the entry is
* already at the desired entry, do nothing.
@@ -2917,7 +2917,7 @@ rename_entry(H5C_t * cache_ptr,
if ( entry_ptr->at_main_addr && !main_addr ) {
- /* rename to alt addr */
+ /* move to alt addr */
HDassert( entry_ptr->addr == entry_ptr->main_addr );
@@ -2927,7 +2927,7 @@ rename_entry(H5C_t * cache_ptr,
} else if ( !(entry_ptr->at_main_addr) && main_addr ) {
- /* rename to main addr */
+ /* move to main addr */
HDassert( entry_ptr->addr == entry_ptr->alt_addr );
@@ -3499,7 +3499,7 @@ unprotect_entry_with_size_change(H5F_t * file_ptr,
* Function: row_major_scan_forward()
*
- * Purpose: Do a sequence of inserts, protects, unprotects, renames,
+ * Purpose: Do a sequence of inserts, protects, unprotects, moves,
* destroys while scanning through the set of entries. If
* pass is false on entry, do nothing.
@@ -3919,7 +3919,7 @@ hl_row_major_scan_forward(H5F_t * file_ptr,
* Function: row_major_scan_backward()
*
- * Purpose: Do a sequence of inserts, protects, unprotects, renames,
+ * Purpose: Do a sequence of inserts, protects, unprotects, moves,
* destroys while scanning backwards through the set of
* entries. If pass is false on entry, do nothing.